@@ -23,16 +23,21 @@ class Context(object):
     # want a user to flag the commits, etc.
     user = None
     
-    def __init__(self, working_dir, auth=None):
+    def __init__(self, working_dir, auth=None, timeout=-1):
         """working_dir is the working directory in which commands should
         run. auth is a dictionary of authentication information:
         
         * type: 'ssh' or 'password'
         * key: for SSH, this should be the path to the user's private key
         * username: for SSH or password auth, this is the username to use
-        * password: for password auth, this is the password to use"""
+        * password: for password auth, this is the password to use
+        
+        timeout is the time (in seconds) that the command is allowed
+        to run.
+        """
         self.working_dir = path(working_dir)
         self.auth = auth
+        self.timeout = timeout
         
     def _normalize_path(self, unnorm_path):
         norm_path = self.working_dir / path(unnorm_path)
@@ -174,7 +179,8 @@ def run_command(command, context):
     log.debug("Running: %s", (command_line,))
     log.debug("Working dir: %s", context.working_dir)
     
-    returncode, stdout = run_in_directory(context.working_dir, command_line)
+    returncode, stdout = run_in_directory(context.working_dir, command_line, 
+        timeout=context.timeout)
     
     if returncode == 0 and hasattr(command, "command_successful"):
         command.command_successful()
