@@ -3,6 +3,8 @@ import os
 import re
 import glob
 
+import argparse
+
 from uvc.commands import UVCError, DialectCommand, StatusOutput, BaseCommand,\
                         SimpleStringOutput
 from uvc.exc import RepositoryAlreadyInitialized
@@ -11,6 +13,14 @@ from uvc import util
 class SVNError(UVCError):
     """A Subversion-specific error."""
     pass
+    
+class OptionParser(argparse.ArgumentParser):
+    def __init__(self, *args, **kw):
+        kw['add_help'] = False
+        argparse.ArgumentParser.__init__(self, *args, **kw)
+        
+    def exit(self, status=0, msg=""):
+        raise SVNError(msg)
 
 class SVNCommand(DialectCommand):
     dialect_name = "svn"
@@ -190,33 +200,58 @@ class revert(SVNCommand):
             finally:
                 os.chdir(pwd)
         return parts
-
+        
+class SVNNativeCommand(object):
+    @classmethod
+    def from_args(cls, context, initial_args):
+        (options, args) = cls.parser.parse_args(initial_args)
+        return cls(context, initial_args, options, args)
+        
+    def __init__(self, context, initial_args, options, args):
+        self.context = context
+        self.initial_args = initial_args
+        self.options = options
+        self.args = args
+        
+    def command_parts(self):
+        return [self.__class__.__name__[4:]] + self.initial_args
+        
+    def get_command_line(self):
+        return ["svn"] + self.command_parts()
+        
+class SVN_revert(SVNNativeCommand):
+    reads_remote = False
+    writes_remote = False
+    
+    parser = OptionParser()
+    parser.add_argument("-h", "--help", type=bool)
+    parser.add_argument("-R", type=bool)
+    
 class SVNDialect(object):
     
     name = "svn"
     
     def convert(self, command_object):
         """Converts to an SVN-specific command."""
-        local_command = self.get_dialect_command_class(command_object.__class__.__name__)
+        local_command = self._get_command_class(command_object.__class__.__name__)
         return local_command(command_object)
         
     def convert_class(self, command_class):
         """Converts a generic command class to its equivalent."""
-        local_command_class = self.get_dialect_command_class(command_class.__name__)
+        local_command_class = self._get_command_class(command_class.__name__)
         return local_command_class
         
-    def get_dialect_command_class(self, command_name):
+    def _get_command_class(self, command_name):
         """Looks up an svn-specific command class."""
         local_command = globals().get(command_name)
         if not local_command:
             raise SVNError("Command cannot be converted to svn: %s" 
                             % (command_name))
         return local_command
-    
-    def get_dialect_command(self, context, command_name, args):
-        """Looks up an svn-specific command."""
-        local_command = self.get_dialect_command_class(command_name, args)
-        return local_command.from_args(context, args)
+        
+    def get_dialect_command_class(self, command_name):
+        """Looks up an svn-specific command class"""
+        return self._get_command_class("SVN_" + command_name)
     
     def cwd_is_this_dialect(self):
         """Returns 1 if the .svn directory is here, 2 otherwise. svn
